import { HttpClient, MaybeContext, BuildRESTFunction } from '@wix/sdk-types';
import { D as DataCollection, G as GetDataCollectionOptions, L as ListDataCollectionsOptions, a as ListDataCollectionsResponse } from './data-v2-data-collection-collections.universal-DFG8hhGA.js';
export { A as AccessLevel, aV as ActionEvent, a5 as AllowedDataPermissions, B as ArraySizeRange, az as BulkGetDataCollectionsPageBySnapshotsRequest, aA as BulkGetDataCollectionsPageBySnapshotsResponse, aj as BulkGetDataCollectionsRequest, ak as BulkGetDataCollectionsResponse, u as Calculator, v as CalculatorPatternOneOf, J as CmsOptions, k as CollectionCapabilities, d as CollectionOperation, C as CollectionType, aZ as CreateDataCollectionFieldOptions, ar as CreateDataCollectionFieldRequest, as as CreateDataCollectionFieldResponse, ab as CreateDataCollectionRequest, ac as CreateDataCollectionResponse, aF as CreateDataCollectionsSnapshotRequest, aG as CreateDataCollectionsSnapshotResponse, aN as CreateMigratedCollectionsSnapshotRequest, aO as CreateMigratedCollectionsSnapshotResponse, a7 as DataCollectionChangedEvent, a6 as DataCollectionClonedEvent, aa as DataCollectionEvictedEvent, c as DataOperation, a4 as DataPermissions, a$ as DeleteDataCollectionFieldOptions, av as DeleteDataCollectionFieldRequest, aw as DeleteDataCollectionFieldResponse, an as DeleteDataCollectionRequest, ao as DeleteDataCollectionResponse, aL as DeleteDataCollectionsSnapshotRequest, aM as DeleteDataCollectionsSnapshotResponse, aI as Destination, b as Direction, aP as DomainEvent, aQ as DomainEventBodyOneOf, aR as EntityCreatedEvent, aU as EntityDeletedEvent, aT as EntityUpdatedEvent, aE as Failure, n as Field, r as FieldCapabilities, E as FieldPlugin, H as FieldPluginOptionsOneOf, F as FieldPluginType, o as FieldRangeValidationsOneOf, a8 as FieldUpdate, t as FieldsPattern, e as Format, ad as GetDataCollectionRequest, ae as GetDataCollectionResponse, aX as IdentificationData, aY as IdentificationDataIdOneOf, aC as Index, aD as IndexField, l as IndexLimits, m as IndexQuotaLimits, i as IndexSource, I as IndexStatus, af as ListDataCollectionsRequest, aW as MessageEnvelope, M as MultiReference, a1 as MultilingualOptions, N as NumberRange, s as ObjectField, O as Order, y as PageLink, a2 as PageLinkPluginOptions, ah as Paging, ai as PagingMetadataV2, f as PagingMode, K as Permissions, V as Plugin, a3 as PluginCmsOptions, X as PluginOptionsOneOf, P as PluginType, a9 as PluginUpdate, Z as PublishPluginOptions, Q as QueryOperator, w as Reference, aJ as RestorationCollection, ap as RestoreDataCollectionRequest, aq as RestoreDataCollectionResponse, aH as RestoreDataCollectionsFromSnapshotRequest, aK as RestoreDataCollectionsFromSnapshotResponse, aS as RestoreInfo, R as Role, g as Segment, $ as SingleItemPluginOptions, Y as SiteSort, aB as SnapshotCollection, j as Sort, h as SortOrder, ag as Sorting, S as Status, z as StringLengthRange, T as Type, p as TypeMetadata, q as TypeMetadataMetadataOneOf, a_ as UpdateDataCollectionFieldOptions, at as UpdateDataCollectionFieldRequest, au as UpdateDataCollectionFieldResponse, al as UpdateDataCollectionRequest, am as UpdateDataCollectionResponse, ax as UpdateDataPermissionsRequest, ay as UpdateDataPermissionsResponse, U as UrlizedOnlyPattern, a0 as UrlizedPluginOptions, W as WebhookIdentityType, x as _Array, _ as _Object } from './data-v2-data-collection-collections.universal-DFG8hhGA.js';

declare function createDataCollection$1(httpClient: HttpClient): CreateDataCollectionSignature;
interface CreateDataCollectionSignature {
    /**
     * Creates a new data collection.
     *
     * The request body must include an ID, details for at least 1 field, and a permissions object. If any of these are missing, the collection isn't created.
     * @param - Collection details.
     * @param - Options for creating a data collection.
     * @returns Details of collection created.
     */
    (collection: DataCollection): Promise<DataCollection>;
}
declare function getDataCollection$1(httpClient: HttpClient): GetDataCollectionSignature;
interface GetDataCollectionSignature {
    /**
     * Retrieves a data collection by ID.
     * @param - ID of the collection to retrieve.
     * @param - Options for retrieving a data collection.
     * @returns Details of the collection requested.
     */
    (dataCollectionId: string, options?: GetDataCollectionOptions | undefined): Promise<DataCollection>;
}
declare function listDataCollections$1(httpClient: HttpClient): ListDataCollectionsSignature;
interface ListDataCollectionsSignature {
    /**
     * Retrieves a list of all data collections associated with the site or project.
     *
     * By default, the list is ordered by ID in ascending order.
     * @param - Options for retrieving a list of data collections.
     */
    (options?: ListDataCollectionsOptions | undefined): Promise<ListDataCollectionsResponse>;
}
declare function updateDataCollection$1(httpClient: HttpClient): UpdateDataCollectionSignature;
interface UpdateDataCollectionSignature {
    /**
     * Updates a data collection.
     *
     * A collection ID, revision number, permissions, and at least 1 field must be provided within the `collection` body parameter.
     * If a collection with that ID exists, and if its current `revision` number matches the one provided, it is updated.
     * Otherwise, the request fails.
     *
     * When a collection is updated, its `updatedDate` property is changed to the current date and its `revision` property is incremented.
     *
     * > **Note:**
     * > After a collection is updated, it only contains the properties included in the Update Data Collection request. If the existing collection has properties with values and those properties
     * > aren't included in the updated collection details, their values are lost.
     * @param - Updated collection details. The existing collection is replaced with this version.
     * @param - Options for updating a data collection.
     * @returns Updated collection details.
     */
    (collection: DataCollection): Promise<DataCollection>;
}
declare function deleteDataCollection$1(httpClient: HttpClient): DeleteDataCollectionSignature;
interface DeleteDataCollectionSignature {
    /**
     * Deletes a data collection.
     *
     * > **Note:**
     * > Once a collection is deleted, it can only be restored for limited amount of time.
     * @param - ID of the collection to delete.
     */
    (dataCollectionId: string): Promise<void>;
}

declare const createDataCollection: MaybeContext<BuildRESTFunction<typeof createDataCollection$1> & typeof createDataCollection$1>;
declare const getDataCollection: MaybeContext<BuildRESTFunction<typeof getDataCollection$1> & typeof getDataCollection$1>;
declare const listDataCollections: MaybeContext<BuildRESTFunction<typeof listDataCollections$1> & typeof listDataCollections$1>;
declare const updateDataCollection: MaybeContext<BuildRESTFunction<typeof updateDataCollection$1> & typeof updateDataCollection$1>;
declare const deleteDataCollection: MaybeContext<BuildRESTFunction<typeof deleteDataCollection$1> & typeof deleteDataCollection$1>;

export { DataCollection, GetDataCollectionOptions, ListDataCollectionsOptions, ListDataCollectionsResponse, createDataCollection, deleteDataCollection, getDataCollection, listDataCollections, updateDataCollection };
