import { HttpClient, MaybeContext, BuildRESTFunction } from '@wix/sdk-types';
import { D as DataCollection, G as GetDataCollectionOptions, L as ListDataCollectionsOptions, a as ListDataCollectionsResponse, R as RestoreDataCollectionResponse, C as CreateDataCollectionFieldOptions, b as CreateDataCollectionFieldResponse, U as UpdateDataCollectionFieldOptions, c as UpdateDataCollectionFieldResponse, d as DeleteDataCollectionFieldOptions, e as DeleteDataCollectionFieldResponse } from './data-v2-data-collection-collections.universal-DZ3_N2Cv.js';
export { A as AccessLevel, aY as ActionEvent, ac as AllowedDataPermissions, Y as ArraySizeRange, aC as BulkGetDataCollectionsPageBySnapshotsRequest, aD as BulkGetDataCollectionsPageBySnapshotsResponse, aq as BulkGetDataCollectionsRequest, ar as BulkGetDataCollectionsResponse, E as Calculator, H as CalculatorPatternOneOf, a0 as CmsOptions, q as CollectionCapabilities, i as CollectionOperation, f as CollectionType, ax as CreateDataCollectionFieldRequest, ai as CreateDataCollectionRequest, aj as CreateDataCollectionResponse, aI as CreateDataCollectionsSnapshotRequest, aJ as CreateDataCollectionsSnapshotResponse, aQ as CreateMigratedCollectionsSnapshotRequest, aR as CreateMigratedCollectionsSnapshotResponse, ae as DataCollectionChangedEvent, ad as DataCollectionClonedEvent, ah as DataCollectionEvictedEvent, h as DataOperation, ab as DataPermissions, az as DeleteDataCollectionFieldRequest, au as DeleteDataCollectionRequest, av as DeleteDataCollectionResponse, aO as DeleteDataCollectionsSnapshotRequest, aP as DeleteDataCollectionsSnapshotResponse, aL as Destination, g as Direction, aS as DomainEvent, aT as DomainEventBodyOneOf, aU as EntityCreatedEvent, aX as EntityDeletedEvent, aW as EntityUpdatedEvent, aH as Failure, t as Field, x as FieldCapabilities, Z as FieldPlugin, $ as FieldPluginOptionsOneOf, F as FieldPluginType, u as FieldRangeValidationsOneOf, af as FieldUpdate, z as FieldsPattern, k as Format, ak as GetDataCollectionRequest, al as GetDataCollectionResponse, a_ as IdentificationData, a$ as IdentificationDataIdOneOf, aF as Index, aG as IndexField, r as IndexLimits, s as IndexQuotaLimits, o as IndexSource, I as IndexStatus, am as ListDataCollectionsRequest, aZ as MessageEnvelope, M as MultiReference, a8 as MultilingualOptions, V as NumberRange, y as ObjectField, O as Order, N as PageLink, a9 as PageLinkPluginOptions, ao as Paging, ap as PagingMetadataV2, l as PagingMode, a1 as Permissions, a2 as Plugin, aa as PluginCmsOptions, a3 as PluginOptionsOneOf, P as PluginType, ag as PluginUpdate, a5 as PublishPluginOptions, Q as QueryOperator, J as Reference, aM as RestorationCollection, aw as RestoreDataCollectionRequest, aK as RestoreDataCollectionsFromSnapshotRequest, aN as RestoreDataCollectionsFromSnapshotResponse, aV as RestoreInfo, j as Role, m as Segment, a6 as SingleItemPluginOptions, a4 as SiteSort, aE as SnapshotCollection, p as Sort, n as SortOrder, an as Sorting, S as Status, X as StringLengthRange, T as Type, v as TypeMetadata, w as TypeMetadataMetadataOneOf, ay as UpdateDataCollectionFieldRequest, as as UpdateDataCollectionRequest, at as UpdateDataCollectionResponse, aA as UpdateDataPermissionsRequest, aB as UpdateDataPermissionsResponse, B as UrlizedOnlyPattern, a7 as UrlizedPluginOptions, W as WebhookIdentityType, K as _Array, _ as _Object } from './data-v2-data-collection-collections.universal-DZ3_N2Cv.js';

declare function createDataCollection$1(httpClient: HttpClient): CreateDataCollectionSignature;
interface CreateDataCollectionSignature {
    /**
     * Creates a new data collection.
     *
     * The request body must include an ID, details for at least 1 field, and a permissions object. If any of these are missing, the collection isn't created.
     * @param - Collection details.
     * @param - Options for creating a data collection.
     * @returns Details of collection created.
     */
    (collection: DataCollection): Promise<DataCollection>;
}
declare function getDataCollection$1(httpClient: HttpClient): GetDataCollectionSignature;
interface GetDataCollectionSignature {
    /**
     * Retrieves a data collection by ID.
     * @param - ID of the collection to retrieve.
     * @param - Options for retrieving a data collection.
     * @returns Details of the collection requested.
     */
    (dataCollectionId: string, options?: GetDataCollectionOptions | undefined): Promise<DataCollection>;
}
declare function listDataCollections$1(httpClient: HttpClient): ListDataCollectionsSignature;
interface ListDataCollectionsSignature {
    /**
     * Retrieves a list of all data collections associated with the site or project.
     *
     * By default, the list is ordered by ID in ascending order.
     * @param - Options for retrieving a list of data collections.
     */
    (options?: ListDataCollectionsOptions | undefined): Promise<ListDataCollectionsResponse>;
}
declare function updateDataCollection$1(httpClient: HttpClient): UpdateDataCollectionSignature;
interface UpdateDataCollectionSignature {
    /**
     * Updates a data collection.
     *
     * A collection ID, revision number, permissions, and at least 1 field must be provided within the `collection` body parameter.
     * If a collection with that ID exists, and if its current `revision` number matches the one provided, it is updated.
     * Otherwise, the request fails.
     *
     * When a collection is updated, its `updatedDate` property is changed to the current date and its `revision` property is incremented.
     *
     * > **Note:**
     * > After a collection is updated, it only contains the properties included in the Update Data Collection request. If the existing collection has properties with values and those properties
     * > aren't included in the updated collection details, their values are lost.
     * @param - Updated collection details. The existing collection is replaced with this version.
     * @param - Options for updating a data collection.
     * @returns Updated collection details.
     */
    (collection: DataCollection): Promise<DataCollection>;
}
declare function deleteDataCollection$1(httpClient: HttpClient): DeleteDataCollectionSignature;
interface DeleteDataCollectionSignature {
    /**
     * Deletes a data collection.
     *
     * > **Note:**
     * > Once a collection is deleted, it can only be restored for limited amount of time.
     * @param - ID of the collection to delete.
     */
    (dataCollectionId: string): Promise<void>;
}
/** @internal */
declare function restoreDataCollection$1(httpClient: HttpClient): RestoreDataCollectionSignature;
interface RestoreDataCollectionSignature {
    /**
     * Restores recently deleted collection.
     *
     * Fails with `WDE0025` if collection was deleted too long ago or has never existed.
     * @param - Data Collection ID to restore
     */
    (dataCollectionId: string): Promise<RestoreDataCollectionResponse>;
}
/** @internal */
declare function createDataCollectionField$1(httpClient: HttpClient): CreateDataCollectionFieldSignature;
interface CreateDataCollectionFieldSignature {
    /**
     * Adds new field to data collection schema
     * @param - ID of data collection to update
     */
    (dataCollectionId: string, options: CreateDataCollectionFieldOptions): Promise<CreateDataCollectionFieldResponse>;
}
/** @internal */
declare function updateDataCollectionField$1(httpClient: HttpClient): UpdateDataCollectionFieldSignature;
interface UpdateDataCollectionFieldSignature {
    /**
     * Updates data collection field
     * @param - ID of data collection to update
     */
    (dataCollectionId: string, options: UpdateDataCollectionFieldOptions): Promise<UpdateDataCollectionFieldResponse>;
}
/** @internal */
declare function deleteDataCollectionField$1(httpClient: HttpClient): DeleteDataCollectionFieldSignature;
interface DeleteDataCollectionFieldSignature {
    /**
     * Deletes data collection field
     * @param - ID of data collection to update
     */
    (dataCollectionId: string, options: DeleteDataCollectionFieldOptions): Promise<DeleteDataCollectionFieldResponse>;
}

declare const createDataCollection: MaybeContext<BuildRESTFunction<typeof createDataCollection$1> & typeof createDataCollection$1>;
declare const getDataCollection: MaybeContext<BuildRESTFunction<typeof getDataCollection$1> & typeof getDataCollection$1>;
declare const listDataCollections: MaybeContext<BuildRESTFunction<typeof listDataCollections$1> & typeof listDataCollections$1>;
declare const updateDataCollection: MaybeContext<BuildRESTFunction<typeof updateDataCollection$1> & typeof updateDataCollection$1>;
declare const deleteDataCollection: MaybeContext<BuildRESTFunction<typeof deleteDataCollection$1> & typeof deleteDataCollection$1>;
/** @internal */
declare const restoreDataCollection: MaybeContext<BuildRESTFunction<typeof restoreDataCollection$1> & typeof restoreDataCollection$1>;
/** @internal */
declare const createDataCollectionField: MaybeContext<BuildRESTFunction<typeof createDataCollectionField$1> & typeof createDataCollectionField$1>;
/** @internal */
declare const updateDataCollectionField: MaybeContext<BuildRESTFunction<typeof updateDataCollectionField$1> & typeof updateDataCollectionField$1>;
/** @internal */
declare const deleteDataCollectionField: MaybeContext<BuildRESTFunction<typeof deleteDataCollectionField$1> & typeof deleteDataCollectionField$1>;

export { CreateDataCollectionFieldOptions, CreateDataCollectionFieldResponse, DataCollection, DeleteDataCollectionFieldOptions, DeleteDataCollectionFieldResponse, GetDataCollectionOptions, ListDataCollectionsOptions, ListDataCollectionsResponse, RestoreDataCollectionResponse, UpdateDataCollectionFieldOptions, UpdateDataCollectionFieldResponse, createDataCollection, createDataCollectionField, deleteDataCollection, deleteDataCollectionField, getDataCollection, listDataCollections, restoreDataCollection, updateDataCollection, updateDataCollectionField };
